"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var TestHelpers_1 = require("../parser/__tests__/TestHelpers");
var TSDocParserConfiguration_1 = require("../parser/TSDocParserConfiguration");
test('01 Simple @beta and @internal extraction', function () {
    var parserContext = TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/**',
        ' * START @beta',
        ' * @unknownTag',
        ' * @internal @internal END',
        ' */'
    ].join('\n'));
    var docComment = parserContext.docComment;
    var modifierTagSet = docComment.modifierTagSet;
    expect(modifierTagSet.isAlpha()).toEqual(false);
    expect(modifierTagSet.isBeta()).toEqual(true);
    expect(modifierTagSet.isInternal()).toEqual(true);
});
test('02 A basic TSDoc comment with all components', function () {
    var configuration = new TSDocParserConfiguration_1.TSDocParserConfiguration();
    configuration.addTagDefinitions([
        new TSDocParserConfiguration_1.TSDocTagDefinition({
            tagName: '@customBlock',
            syntaxKind: TSDocParserConfiguration_1.TSDocTagSyntaxKind.BlockTag
        }),
        new TSDocParserConfiguration_1.TSDocTagDefinition({
            tagName: '@customModifier',
            syntaxKind: TSDocParserConfiguration_1.TSDocTagSyntaxKind.ModifierTag
        })
    ]);
    var parserContext = TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/**',
        ' * Adds two numbers together.',
        ' *',
        ' * @remarks',
        ' * This method is part of the {@link core-library/Math | Math subsystem}.',
        ' *',
        ' * @customBlock',
        ' * This is a custom block containing an @undefinedBlockTag',
        ' *',
        ' * @param x - The first number to add',
        ' * @param y - The second number to add',
        ' * @returns The sum of `x` and `y`',
        ' *',
        ' * @beta @customModifier',
        ' */'
    ].join('\n'), configuration);
    var docComment = parserContext.docComment;
    expect(docComment.modifierTagSet.hasModifierTag('@customModifier')).toEqual(true);
});
test('03 Jumbled order', function () {
    var configuration = new TSDocParserConfiguration_1.TSDocParserConfiguration();
    configuration.addTagDefinitions([
        new TSDocParserConfiguration_1.TSDocTagDefinition({
            tagName: '@customBlock',
            syntaxKind: TSDocParserConfiguration_1.TSDocTagSyntaxKind.BlockTag
        }),
        new TSDocParserConfiguration_1.TSDocTagDefinition({
            tagName: '@customModifier',
            syntaxKind: TSDocParserConfiguration_1.TSDocTagSyntaxKind.ModifierTag
        })
    ]);
    var parserContext = TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/**',
        ' * Adds two numbers together. @remarks This method is part of the',
        ' * {@link core-library/Math | Math subsystem}.',
        ' * @beta @customModifier',
        ' * @returns The sum of `x` and `y`',
        ' * @param x - The first number to add @param y - The second number to add',
        ' * @customBlock',
        ' * This is a custom block containing an @undefinedBlockTag',
        ' */'
    ].join('\n'), configuration);
    var docComment = parserContext.docComment;
    expect(docComment.modifierTagSet.hasModifierTag('@customModifier')).toEqual(true);
});
test('03 Incomplete @param blocks', function () {
    TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/**',
        ' * @param - The first number to add',
        ' * @param y The first number to add',
        ' * @returns The sum of `x` and `y`',
        ' */'
    ].join('\n'));
});
//# sourceMappingURL=ParsingBasics.test.js.map