import { DocBlockTag } from '../nodes/DocBlockTag';
/**
 * Represents a set of modifier tags that were extracted from a doc comment.
 *
 * @remarks
 * TSDoc modifier tags are block tags that do not have any associated rich text content.
 * Instead, their presence or absence acts as an on/off switch, indicating some aspect
 * of the underlying API item.  For example, the `@internal` modifier indicates that a
 * signature is internal (i.e. not part of the public API contract).
 */
export declare class ModifierTagSet {
    private readonly _nodes;
    private readonly _names;
    /**
     * The original block tag nodes that defined the modifiers in this set.
     */
    readonly nodes: ReadonlyArray<DocBlockTag>;
    /**
     * Returns true if a DocBlockTag with the specified tag name was added to this set.
     * Note that synonyms are not considered.  The comparison is case-insensitive.
     * @param tagName - The name of the tag, including the `@` prefix  For example, `@internal`
     */
    hasModifierTag(modifierTag: string): boolean;
    /**
     * Returns true if a DocBlockTag with the specified tag name was added to this set.
     * Note that synonyms are not considered.  The comparison is case-insensitive.
     * @param tagName - The name of the tag, including the `@` prefix  For example, `@internal`
     */
    hasModifierTagWithUpperCase(alreadyUpperCaseModifierTag: string): boolean;
    /**
     * Adds a new modifier tag to the set.  If a tag already exists with the same name,
     * then no change is made, and the return value is false.
     */
    addModifierTag(blockTag: DocBlockTag): boolean;
}
