import { DocNode, DocNodeKind, IDocNodeParameters } from './DocNode';
/**
 * Constructor parameters for {@link DocBlockTag}.
 */
export interface IDocBlockTagParameters extends IDocNodeParameters {
    tagName: string;
}
/**
 * Represents a TSDoc block tag such as `@param` or `@public`.
 */
export declare class DocBlockTag extends DocNode {
    /** {@inheritdoc} */
    readonly kind: DocNodeKind;
    /**
     * The TSDoc tag name.  TSDoc tag names start with an at-sign ("@") followed
     * by ASCII letters using "camelCase" capitalization.
     */
    readonly tagName: string;
    /**
     * The TSDoc tag name in all capitals, which is used for performing
     * case-insensitive comparisons or lookups.
     */
    readonly tagNameWithUpperCase: string;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocBlockTagParameters);
}
