import { DocNode, DocNodeKind, IDocNodeParameters } from './DocNode';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocHtmlEndTag}.
 */
export interface IDocHtmlEndTagParameters extends IDocNodeParameters {
    openingDelimiterExcerpt?: Excerpt;
    elementNameExcerpt?: Excerpt;
    elementName: string;
    closingDelimiterExcerpt?: Excerpt;
}
/**
 * Represents an HTML end tag.  Example: `</a>`
 */
export declare class DocHtmlEndTag extends DocNode {
    /** {@inheritdoc} */
    readonly kind: DocNodeKind;
    private readonly _openingDelimiterParticle;
    private readonly _elementNameParticle;
    private readonly _closingDelimiterParticle;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocHtmlEndTagParameters);
    /**
     * The HTML element name.
     */
    readonly elementName: string;
    /**
     * {@inheritdoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
