import { DocNode, DocNodeKind, IDocNodeParameters } from './DocNode';
import { DocHtmlAttribute } from './DocHtmlAttribute';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocHtmlStartTag}.
 */
export interface IDocHtmlStartTagParameters extends IDocNodeParameters {
    openingDelimiterExcerpt?: Excerpt;
    elementNameExcerpt?: Excerpt;
    elementName: string;
    spacingAfterElementName?: string;
    htmlAttributes: DocHtmlAttribute[];
    selfClosingTag: boolean;
    closingDelimiterExcerpt?: Excerpt;
}
/**
 * Represents an HTML start tag, which may or may not be self-closing.
 *
 * Example: `<a href="#" />`
 */
export declare class DocHtmlStartTag extends DocNode {
    /** {@inheritdoc} */
    readonly kind: DocNodeKind;
    /**
     * If true, then the HTML tag ends with "/>" instead of ">".
     */
    readonly selfClosingTag: boolean;
    private readonly _openingDelimiterParticle;
    private readonly _elementNameParticle;
    private _htmlAttributes;
    private readonly _closingDelimiterParticle;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocHtmlStartTagParameters);
    /**
     * The HTML element name.
     */
    readonly elementName: string;
    /**
     * The HTML attributes belonging to this HTML element.
     */
    readonly htmlAttributes: ReadonlyArray<DocHtmlAttribute>;
    /**
     * Explicit whitespace that a renderer should insert after the HTML element name.
     * If undefined, then the renderer can use a formatting rule to generate appropriate spacing.
     */
    readonly spacingAfterElementName: string | undefined;
    /**
     * {@inheritdoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
