import { DocNodeKind, IDocNodeParameters, DocNode } from './DocNode';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocInlineTag}.
 */
export interface IDocInlineTagParameters extends IDocNodeParameters {
    openingDelimiterExcerpt?: Excerpt;
    tagNameExcerpt?: Excerpt;
    tagName: string;
    tagContentExcerpt?: Excerpt;
    tagContent: string;
    closingDelimiterExcerpt?: Excerpt;
}
/**
 * Represents a TSDoc inline tag such as `{@inheritdoc}` or `{@link}`.
 */
export declare class DocInlineTag extends DocNode {
    /** {@inheritdoc} */
    readonly kind: DocNodeKind;
    private readonly _openingDelimiterParticle;
    private readonly _tagNameParticle;
    private readonly _tagContentParticle;
    private readonly _closingDelimiterParticle;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocInlineTagParameters);
    /**
     * The TSDoc tag name.
     * For example, if the inline tag is `{@link Guid.toString | the toString() method}`
     * then the tag name would be `@link`.
     */
    readonly tagName: string;
    /**
     * The tag content.
     * For example, if the inline tag is `{@link Guid.toString | the toString() method}`
     * then the tag content would be `Guid.toString | the toString() method`.
     */
    readonly tagContent: string;
    /**
     * {@inheritdoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
