import { Excerpt } from '../parser/Excerpt';
/**
 * Indicates the type of {@link DocNode}.
 */
export declare const enum DocNodeKind {
    Block = "Block",
    BlockTag = "BlockTag",
    CodeSpan = "CodeSpan",
    Comment = "Comment",
    ErrorText = "ErrorText",
    EscapedText = "EscapedText",
    HtmlAttribute = "HtmlAttribute",
    HtmlEndTag = "HtmlEndTag",
    HtmlStartTag = "HtmlStartTag",
    InlineTag = "InlineTag",
    Particle = "Particle",
    Paragraph = "Paragraph",
    ParamBlock = "ParamBlock",
    PlainText = "PlainText",
    Section = "Section",
    SoftBreak = "SoftBreak"
}
/**
 * Constructor parameters for {@link DocNode}.
 */
export interface IDocNodeParameters {
    excerpt?: Excerpt;
}
/**
 * The base class for the parser's Abstract Syntax Tree nodes.
 */
export declare abstract class DocNode {
    private static _badSpacingRegExp;
    /**
     * Indicates the kind of DocNode.
     */
    abstract readonly kind: DocNodeKind;
    /**
     * If this DocNode was created by parsing an input, the `DocNode.excerpt`
     * property can be used to track the associated input text.  This can be useful
     * for highlighting matches during refatoring or highlighting error locations.
     */
    excerpt: Excerpt | undefined;
    protected static validateSpacing(spacing: string | undefined, parameterName: string): void;
    constructor(parameters: IDocNodeParameters);
    /**
     * Returns the list of child nodes for this node.  This is useful for visitors that want
     * to scan the tree looking for nodes of a specific type, without having to process
     * intermediary nodes.
     * @virtual
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
