"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * The base class for the parser's Abstract Syntax Tree nodes.
 */
var DocNode = /** @class */ (function () {
    function DocNode(parameters) {
        /**
         * If this DocNode was created by parsing an input, the `DocNode.excerpt`
         * property can be used to track the associated input text.  This can be useful
         * for highlighting matches during refatoring or highlighting error locations.
         */
        this.excerpt = undefined;
        this.excerpt = parameters.excerpt;
    }
    DocNode.validateSpacing = function (spacing, parameterName) {
        if (spacing) {
            var match = DocNode._badSpacingRegExp.exec(spacing);
            if (match) {
                var badCharacter = match[0];
                throw new Error("The \"" + parameterName + "\" value contains a non-whitespace character \"" + badCharacter + "\"");
            }
        }
    };
    /**
     * Returns the list of child nodes for this node.  This is useful for visitors that want
     * to scan the tree looking for nodes of a specific type, without having to process
     * intermediary nodes.
     * @virtual
     */
    DocNode.prototype.getChildNodes = function () {
        return [];
    };
    DocNode._badSpacingRegExp = /\S/;
    return DocNode;
}());
exports.DocNode = DocNode;
//# sourceMappingURL=DocNode.js.map