import { DocNodeKind, DocNode } from './DocNode';
import { DocBlock, IDocBlockParameters } from './DocBlock';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocParamBlock}.
 */
export interface IDocParamBlockParameters extends IDocBlockParameters {
    parameterNameExcerpt?: Excerpt;
    parameterName: string;
    hyphenExcerpt?: Excerpt;
}
/**
 * Represents a parsed `@param` block, which provides a description for a
 * function parameter.
 */
export declare class DocParamBlock extends DocBlock {
    /** {@inheritdoc} */
    readonly kind: DocNodeKind;
    private readonly _parameterNameParticle;
    private readonly _hyphenParticle;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocParamBlockParameters);
    /**
     * The name of the parameter that is being documented.
     * For example "width" in `@param width - the width of the object`.
     */
    readonly parameterName: string;
    /**
     * {@inheritdoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
