import { DocNode, DocNodeKind, IDocNodeParameters } from './DocNode';
/**
 * Constructor parameters for {@link DocSection}.
 */
export interface IDocSectionParameters extends IDocNodeParameters {
}
/**
 * Represents a general block of rich text.  DocSection is the base class for DocNode classes that
 * act as a simple container for other child nodes.
 */
export declare class DocSection extends DocNode {
    /** {@inheritdoc} */
    readonly kind: DocNodeKind;
    private readonly _nodes;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocSectionParameters);
    /**
     * The child nodes.  Note that for subclasses {@link getChildNodes()} may enumerate
     * additional nodes that are not part of this collection.
     */
    readonly nodes: ReadonlyArray<DocNode>;
    /**
     * {@inheritdoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
    /**
     * Returns true if the specified `docNode` is allowed to be added as a child node.
     * The {@link appendNode()} and {@link appendNodes()} functions use this to validate their
     * inputs.
     *
     * @virtual
     */
    isAllowedChildNode(docNode: DocNode): boolean;
    /**
     * Append a node to the collection.
     */
    appendNode(docNode: DocNode): void;
    appendNodes(docNodes: ReadonlyArray<DocNode>): void;
}
