"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var DocNode_1 = require("./DocNode");
/**
 * Represents a general block of rich text.  DocSection is the base class for DocNode classes that
 * act as a simple container for other child nodes.
 */
var DocSection = /** @class */ (function (_super) {
    __extends(DocSection, _super);
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    function DocSection(parameters) {
        var _this = _super.call(this, parameters) || this;
        /** {@inheritdoc} */
        _this.kind = "Section" /* Section */;
        _this._nodes = [];
        return _this;
    }
    Object.defineProperty(DocSection.prototype, "nodes", {
        /**
         * The child nodes.  Note that for subclasses {@link getChildNodes()} may enumerate
         * additional nodes that are not part of this collection.
         */
        get: function () {
            return this._nodes;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * {@inheritdoc}
     * @override
     */
    DocSection.prototype.getChildNodes = function () {
        return this._nodes;
    };
    /**
     * Returns true if the specified `docNode` is allowed to be added as a child node.
     * The {@link appendNode()} and {@link appendNodes()} functions use this to validate their
     * inputs.
     *
     * @virtual
     */
    DocSection.prototype.isAllowedChildNode = function (docNode) {
        switch (docNode.kind) {
            case "BlockTag" /* BlockTag */:
            case "CodeSpan" /* CodeSpan */:
            case "ErrorText" /* ErrorText */:
            case "EscapedText" /* EscapedText */:
            case "HtmlStartTag" /* HtmlStartTag */:
            case "HtmlEndTag" /* HtmlEndTag */:
            case "InlineTag" /* InlineTag */:
            case "Paragraph" /* Paragraph */:
            case "PlainText" /* PlainText */:
            case "SoftBreak" /* SoftBreak */:
                return true;
        }
        return false;
    };
    /**
     * Append a node to the collection.
     */
    DocSection.prototype.appendNode = function (docNode) {
        if (!this.isAllowedChildNode(docNode)) {
            throw new Error("A DocSection cannot contain nodes of type " + docNode.kind);
        }
        this._nodes.push(docNode);
    };
    DocSection.prototype.appendNodes = function (docNodes) {
        for (var _i = 0, docNodes_1 = docNodes; _i < docNodes_1.length; _i++) {
            var docNode = docNodes_1[_i];
            this.appendNode(docNode);
        }
    };
    return DocSection;
}(DocNode_1.DocNode));
exports.DocSection = DocSection;
//# sourceMappingURL=DocSection.js.map