"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var TokenSequence_1 = require("./TokenSequence");
/**
 * When a DocNode is constructed by parsing input text, the Excerpt object is used to
 * annotate each node with the associated tokens that were parsed.  This is useful
 * e.g. for highlighting the corresponding input characters to indicate a refactoring
 * match or error location.
 *
 * @remarks
 * The excerpt is separated into two token sequences: The "content" sequence is
 * the main textual content for the node.  The "spacingAfterContent" optionally captures
 * following whitespace, in cases where that whitespace is not interesting.
 * (For example, it is not used with DocPlainText since spacing is part of the normal
 * plain text content.)
 */
var Excerpt = /** @class */ (function () {
    function Excerpt(parameters) {
        this.parserContext = parameters.content.parserContext;
        this.content = parameters.content;
        this.spacingAfterContent = parameters.spacingAfterContent || TokenSequence_1.TokenSequence.createEmpty(this.parserContext);
    }
    return Excerpt;
}());
exports.Excerpt = Excerpt;
//# sourceMappingURL=Excerpt.js.map