"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Represents an error or warning that occurred during parsing.
 */
var ParserMessage = /** @class */ (function () {
    function ParserMessage(parameters) {
        this.unformattedText = parameters.messageText;
        this.textRange = parameters.textRange;
        this.tokenSequence = parameters.tokenSequence;
        this.docNode = parameters.docNode;
        this.text = ParserMessage._formatMessageText(this.unformattedText, this.textRange);
    }
    /**
     * Generates a line/column prefix.  Example with line=2 and column=5
     * and message="An error occurred":
     * ```
     * "(2,5): An error occurred"
     * ```
     */
    ParserMessage._formatMessageText = function (message, range) {
        if (!message) {
            message = 'An unknown error occurred';
        }
        if (range.pos !== 0 || range.end !== 0) {
            var location = range.getLocation(range.pos);
            if (location.line) {
                return "(" + location.line + "," + location.column + "): " + message;
            }
        }
        return message;
    };
    ParserMessage.prototype.toString = function () {
        return this.text;
    };
    return ParserMessage;
}());
exports.ParserMessage = ParserMessage;
//# sourceMappingURL=ParserMessage.js.map