"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ParserMessage_1 = require("./ParserMessage");
/**
 * Used to report errors and warnings that occurred during parsing.
 */
var ParserMessageLog = /** @class */ (function () {
    function ParserMessageLog() {
        this._messages = [];
    }
    Object.defineProperty(ParserMessageLog.prototype, "messages", {
        /**
         * The unfiltered list of all messages.
         */
        get: function () {
            return this._messages;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Append a message to the log.
     */
    ParserMessageLog.prototype.addMessage = function (parserMessage) {
        this._messages.push(parserMessage);
    };
    /**
     * Append a message associated with a TextRange.
     */
    ParserMessageLog.prototype.addMessageForTextRange = function (messageText, textRange) {
        this.addMessage(new ParserMessage_1.ParserMessage({
            messageText: messageText,
            textRange: textRange
        }));
    };
    /**
     * Append a message associated with a TokenSequence.
     */
    ParserMessageLog.prototype.addMessageForTokenSequence = function (messageText, tokenSequence, docNode) {
        this.addMessage(new ParserMessage_1.ParserMessage({
            messageText: messageText,
            textRange: tokenSequence.getContainingTextRange(),
            tokenSequence: tokenSequence,
            docNode: docNode
        }));
    };
    /**
     * Append a message associated with a TokenSequence.
     */
    ParserMessageLog.prototype.addMessageForDocErrorText = function (docErrorText) {
        this.addMessage(new ParserMessage_1.ParserMessage({
            messageText: docErrorText.errorMessage,
            textRange: docErrorText.errorLocation.getContainingTextRange(),
            tokenSequence: docErrorText.errorLocation,
            docNode: docErrorText
        }));
    };
    return ParserMessageLog;
}());
exports.ParserMessageLog = ParserMessageLog;
//# sourceMappingURL=ParserMessageLog.js.map